@@ -3,7 +3,7 @@ package RT::Extension::ResetPassword;
 use strict;
 use warnings;
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 =head1 NAME
 
@@ -19,6 +19,10 @@ already have passwords reset their passwords by email.
 There isn't yet an option to only allow privileged or unpriviliged users
 to reset their passwords.
 
+=head1 RT VERSION
+
+Works with RT 4.0, 4.2, 4.4
+
 =head1 INSTALLATION
 
 =over
@@ -67,6 +71,14 @@ If you are upgrading from version 0.05, you will need to run C<make
 initdb> as documented in L<INSTALLATION> to install the Template used by
 this Extension.
 
+To run on RT 4.0 or 4.2, replace this line in the template:
+
+    { RT::Interface::Web::RequestENV('REMOTE_ADDR') }
+
+with this:
+
+    { $ENV{'REMOTE_ADDR'} }
+
 =head1 CONFIGURATION
 
 The contents of the email sent to users can be found in the global
